# Related links
# https://docs.microsoft.com/powershell/scripting/overview
# https://docs.microsoft.com/powershell/scripting/learn/deep-dives/everything-about-if
# https://docs.microsoft.com/powershell/module/microsoft.powershell.core/about/about_regular_expressions

filter msgconv_Renesas_MS
{
    # Remove some progress and status messages from console version CS+
    $_ = $_ -replace '^P:\[Notice\]$', ''
    $_ = $_ -replace '^  \(\d+%\).* \.\.\.$', ''
    $_ = $_ -replace '^\[(Error|Warning|Information)\]', ''

    # Remove some errors and warnings from e2 studio headless build
    $_ = $_ -replace '^Managed Build system.*error:.*', ''
    $_ = $_ -replace '^Warning: NLS.*message:.*', ''

    # In case of e2 studio headless build: convert starting message from Japanese to English
    if ( $_ -match "^eclipsec.exe.* (.*)/(.*)`$" )
    {
        $BuildProj = $Matches.1
        $BuildConfig = $Matches.2
    }
    if ( ( $BuildType -ne "" ) -and ( $BuildConfig -ne "" ) )
    {
        $_ = $_ -replace `
            "^(\d\d:\d\d:\d\d) \*\*\*\*.*(\*\*\*\*)`$", `
            "`$1 **** Build of configuration $BuildConfig for project $BuildProj ****"
    }

    # In case of e2 studio project: ../file(line):Xcode:message --> file(line):Xcode:message 
    $_ = $_ -replace '^\.\./(.*)\((\d+)\):([CEFWM]\d+):(.*)', '$1($2):$3:$4'

    # file(line):Ccode:message --> file(line): error Ccode: message
    # file(line):Ecode:message --> file(line): error Ecode: message
    # file(line):Fcode:message --> file(line): error Fcode: message
    $_ = $_ -replace '(.*)\((\d+)\):([CEF]\d+):(.*)', '$1($2): error $3: $4'

    # file(line):Wcode:message --> file(line): warning Wcode: message
    $_ = $_ -replace '(.*)\((\d+)\):(W\d+):(.*)', '$1($2): warning $3: $4'

    # file(line):Mcode:message --> file(line): info Mcode: message
    $_ = $_ -replace '(.*)\((\d+)\):(M\d+):(.*)', '$1($2): info $3: $4'

    # Show converted message
    if ( $_ -ne '' )
    {
        return $_
    }
}

# e2 studio headless build needs some dedicated care later.
$BuildProj=""
$BuildConfig=""

# e2 studio headless build generates a long (many lines) message to stderr when make is failed.
# Therefore redirect stderr to null to supress the message but it may include other messages...
# cmd.exe /c $PSScriptRoot\$Args 2>&1 | msgconv_Renesas_MS
cmd.exe /c $PSScriptRoot\$Args 2>$null | msgconv_Renesas_MS

# Return exit code of build.bat
exit $LASTEXITCODE
